package WebService::Raygun;
$WebService::Raygun::VERSION = '0.028';
# VERSION

=head1 NAME

=for HTML <a href="https://travis-ci.org/heytrav/raygun4perl"><img src="https://travis-ci.org/heytrav/raygun4perl.svg?branch=master"></a>

WebService::Raygun - Connect to the Raygun.io API

=head1 DESCRIPTION

Send error data to L<Raygun.io|https://raygun.io>

=head1 SEE ALSO

=over 2

=item L<WebService::Raygun::Messenger|WebService::Raygun::Messenger>

This is the entry point for interfacting with L<Raygun|https://raygun.io>.

=back


=cut

use strict;
use warnings;

1;

__END__
